@@ -3,4 +3,5 @@ from datetime import datetime
 
 def wofy():
     now = datetime.now()
-    return f"{now.year}-{now.month}"
+    year, wof, _ = now.isocalendar()
+    return f"{year}-{wof}"
